function [T,Y]=myEulerTemplate(f,Tspan,y0,n)
% Euler's method for solving a single IVP
% Call:
% [T,Y]=myEulerTemplate(f,Tspan,y0,n
% Input arguments:
% f     -- function handle defining the diff. equ.
% Tspan -- vector [a b].
% y0    -- Initial value at the point a.
% n     -- Nr. of subintervals.
% Output arguments:
% T     -- ``Time-vector''
% Y     --  Vector of Euler-solutions at T-points.
%  ... continued on the next slide
% Example:  y'=t+y, y(0)=1
%           f=@(t,y)t+y;
%           [T,Y]=myEuler(f,[0 4],1,6); 
%            plot(T,Y,'*--');grid on
a=Tspan(1);b=Tspan(2);
h=(b-a)/n;
% Complete the code 
....